========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/badges/magnum.svg
    :target: https://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

======
Magnum
======

Magnum is an OpenStack project which offers container orchestration engines
for deploying and managing containers as first class resources in OpenStack.

For more information, please refer to the following resources:

* **Free software:** under the `Apache license <http://www.apache.org/licenses/LICENSE-2.0>`_
* **Documentation:** https://docs.openstack.org/magnum/latest/
* **Source:** http://git.openstack.org/cgit/openstack/magnum
* **Blueprints:** https://blueprints.launchpad.net/magnum
* **Bugs:** https://storyboard.openstack.org/#!/project/openstack/magnum
* **REST Client:** http://git.openstack.org/cgit/openstack/python-magnumclient
* ** Release notes:** https://docs.openstack.org/releasenotes/magnum/index.html
